FormattedDateTimeUncheckedError

Enum FormattedDateTimeUncheckedError 

#[non_exhaustive]
pub enum FormattedDateTimeUncheckedError { InvalidMonthCode(MonthCode), InvalidEra(TinyAsciiStr<16>), InvalidCyclicYear { value: u8, max: u8, }, NamesNotLoaded(ErrorField), DecimalFormatterNotLoaded, MissingInputField(MissingInputFieldKind), UnsupportedField(ErrorField), UnsupportedLength(ErrorField), }
Error for the TryWriteable implementation of FormattedDateTimeUnchecked.

There are 3 general conditions for these errors to occur:

  1. Invariants of unchecked functions are not upheld
  2. Invariants of locale data are not upheld
  3. Invariants of trait impls are not upheld (including [scaffolding traits])

It is not always possible to distinguish the source of the errors. Each variant is documented with rules of thumb for when they might occur.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidMonthCode(MonthCode)

The MonthCode of the input is not valid for this calendar.

Error conditions:

  • Unchecked functions: for example, wrong calendar passed to set_date_fields_unchecked
  • Locale data: for example, datetime names don’t match the formatter’s calendar
  • Trait impls: for example, the date returns fields for the wrong calendar

The output will contain the raw MonthCode as a fallback value.



InvalidEra(TinyAsciiStr<16>)

The era code of the input is not valid for this calendar.

Same error conditions as FormattedDateTimeUncheckedError::InvalidMonthCode.

The output will contain the era code as the fallback.



InvalidCyclicYear

The [CyclicYear::year] of the input is not valid for this calendar.

Same error conditions as FormattedDateTimeUncheckedError::InvalidMonthCode.

The output will contain [CyclicYear::related_iso] as a fallback value.

Fields

value: u8

Value

max: u8

Max



NamesNotLoaded(ErrorField)

The localized names for a field have not been loaded.

Error conditions:

  • Locale data: for example, year style patterns contain inconsistant field lengths
  • Trait impls: for example, a custom field set does not include the correct names data

The output will contain fallback values using field identifiers (such as tue for Weekday::Tuesday, M02 for month 2, etc.).



DecimalFormatterNotLoaded

The [DecimalFormatter] has not been loaded.

Same error conditions as FormattedDateTimeUncheckedError::NamesNotLoaded.

The output will contain fallback values using Latin numerals.



MissingInputField(MissingInputFieldKind)

An input field (such as “hour” or “month”) is missing.

Error conditions:

  • Unchecked functions: for example, insufficient fields in DateTimeInputUnchecked
  • Locale data: for example, the pattern contains a field not in the fieldset
  • Trait impls: for example, a custom field set does not require the correct fields

The output will contain the string {X} instead, where X is the symbol for which the input is missing.



UnsupportedField(ErrorField)

The pattern contains a field symbol for which formatting is unsupported.

Error conditions:

  • Locale data: the pattern contains an unsupported field

The output will contain the string {unsupported:X}, where X is the symbol of the unsupported field.



UnsupportedLength(ErrorField)

The pattern contains a field that has a valid symbol but invalid length.

Same error conditions as FormattedDateTimeUncheckedError::UnsupportedField.

The output will contain fallback values similar to FormattedDateTimeUncheckedError::NamesNotLoaded.