#[non_exhaustive]pub enum Fallback {
Code,
None,
}Expand description
An enum for fallback return when the system does not have the requested display name.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Code
Fall back to the BCP-47 code when display name cannot be found
None
Do not fall back, return an error when the display name cannot be found