#[non_exhaustive]pub struct DisplayNamesOptions {
pub style: Option<Style>,
pub fallback: Fallback,
pub language_display: LanguageDisplay,
}Expand description
A bag of options defining how region or language codes will be translated.
Example
use icu::experimental::displaynames::{
DisplayNamesOptions, RegionDisplayNames, Style,
};
use icu::locale::{locale, subtags::region};
let locale = locale!("en-001");
let mut options: DisplayNamesOptions = Default::default();
options.style = Some(Style::Short);
let display_name = RegionDisplayNames::try_new(locale.into(), options)
.expect("Data should load successfully");
// Full name would be "Bosnia & Herzegovina"
assert_eq!(display_name.of(region!("BA")), Some("Bosnia"));Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.style: Option<Style>The optional formatting style to use for display name.
fallback: FallbackThe fallback return when the system does not have the requested display name, defaults to “code”.
language_display: LanguageDisplayThe language display kind, defaults to “dialect”.