pub struct ZoneNameTimestamp(/* private fields */);Expand description
The moment in time for resolving a time zone name.
What is this for? Most software deals with time zone transitions, computing the UTC offset on a given point in time. In ICU4X, we deal with time zone display names. Whereas time zone transitions occur multiple times per year in some time zones, the set of display names changes more rarely. For example, ICU4X needs to know when a region switches from Eastern Time to Central Time.
This type can only represent display name changes after 1970, and only to a coarse (15-minute) granularity, which is sufficient for CLDR and TZDB data within that time frame.
Examples
The region of Metlakatla (Alaska) used to be on Pacific Time but is now on Alaska Time.
use icu::calendar::Iso;
use icu::datetime::fieldsets::zone::GenericLong;
use icu::datetime::NoCalendarFormatter;
use icu::locale::locale;
use icu::time::zone::TimeZone;
use icu::time::zone::ZoneNameTimestamp;
use icu::time::ZonedDateTime;
use writeable::assert_writeable_eq;
let metlakatla = TimeZone::from_iana_id("America/Metlakatla");
let zone_formatter =
NoCalendarFormatter::try_new(locale!("en-US").into(), GenericLong)
.unwrap();
let time_zone_info_past = metlakatla
.without_offset()
.with_zone_name_timestamp(ZoneNameTimestamp::far_in_past());
let time_zone_info_future = metlakatla
.without_offset()
.with_zone_name_timestamp(ZoneNameTimestamp::far_in_future());
// Check the display names:
let name_past = zone_formatter.format(&time_zone_info_past);
let name_future = zone_formatter.format(&time_zone_info_future);
assert_writeable_eq!(name_past, "Pacific Time");
assert_writeable_eq!(name_future, "Alaska Time");Implementations
Sourceimpl ZoneNameTimestamp
impl ZoneNameTimestamp
Sourcepub fn to_zoned_date_time_iso(self) -> ZonedDateTime<Iso, UtcOffset>
pub fn to_zoned_date_time_iso(self) -> ZonedDateTime<Iso, UtcOffset>
Recovers the UTC datetime for this ZoneNameTimestamp.
This will always return a ZonedDateTime with UtcOffset::zero()
Examples
ZonedDateTime does not necessarily roundtrip:
use icu::calendar::Date;
use icu::time::zone::ZoneNameTimestamp;
use icu::time::{ZonedDateTime, Time, zone::UtcOffset};
let zoned_date_time = ZonedDateTime {
date: Date::try_new_iso(2025, 4, 30).unwrap(),
time: Time::try_new(13, 58, 16, 500000000).unwrap(),
zone: UtcOffset::zero(),
};
let zone_name_timestamp = ZoneNameTimestamp::from_zoned_date_time(zoned_date_time);
let recovered_zoned_date_time = zone_name_timestamp.to_zoned_date_time_iso();
// The datetime doesn't roundtrip:
assert_ne!(zoned_date_time, recovered_zoned_date_time);
// The exact behavior is subject to change. For illustration only:
assert_eq!(recovered_zoned_date_time.date, zoned_date_time.date);
assert_eq!(recovered_zoned_date_time.time.hour, zoned_date_time.time.hour);
assert_eq!(recovered_zoned_date_time.time.minute.number(), 45); // rounded down
assert_eq!(recovered_zoned_date_time.time.second.number(), 0); // always zero
assert_eq!(recovered_zoned_date_time.time.subsecond.number(), 0); // always zeroSourcepub fn from_zoned_date_time<C>(
zoned_date_time: ZonedDateTime<C, UtcOffset>,
) -> ZoneNameTimestampwhere
C: AsCalendar,
pub fn from_zoned_date_time<C>(
zoned_date_time: ZonedDateTime<C, UtcOffset>,
) -> ZoneNameTimestampwhere
C: AsCalendar,
Creates an instance of ZoneNameTimestamp from a ZonedDateTime with an explicit UtcOffset.
Sourcepub fn from_zoned_date_time_iso(
zoned_date_time: ZonedDateTime<Iso, UtcOffset>,
) -> ZoneNameTimestamp
👎Deprecated since 2.2.0: use Self::from_zoned_date_time
pub fn from_zoned_date_time_iso( zoned_date_time: ZonedDateTime<Iso, UtcOffset>, ) -> ZoneNameTimestamp
use Self::from_zoned_date_time
Sourcepub fn from_epoch_seconds(seconds: i64) -> ZoneNameTimestamp
pub fn from_epoch_seconds(seconds: i64) -> ZoneNameTimestamp
Creates an instance of ZoneNameTimestamp from a number of seconds since the UNIX epoch.
Sourcepub fn to_date_time_iso(self) -> DateTime<Iso>
👎Deprecated since 2.1.0: returns a UTC DateTime, which is the wrong type. Use to_zoned_date_time_iso instead
pub fn to_date_time_iso(self) -> DateTime<Iso>
returns a UTC DateTime, which is the wrong type. Use to_zoned_date_time_iso instead
Recovers the UTC datetime for this ZoneNameTimestamp.
Sourcepub fn from_date_time_iso(_: DateTime<Iso>) -> ZoneNameTimestamp
👎Deprecated since 2.1.0: implicitly interprets the DateTime as UTC. Use from_zoned_date_time_iso instead.
pub fn from_date_time_iso(_: DateTime<Iso>) -> ZoneNameTimestamp
implicitly interprets the DateTime as UTC. Use from_zoned_date_time_iso instead.
Creates an instance of ZoneNameTimestamp from a UTC datetime.
The datetime might be clamped and might lose precision.
Sourcepub fn far_in_past() -> ZoneNameTimestamp
pub fn far_in_past() -> ZoneNameTimestamp
Returns a ZoneNameTimestamp for a time far in the past.
Sourcepub fn far_in_future() -> ZoneNameTimestamp
pub fn far_in_future() -> ZoneNameTimestamp
Returns a ZoneNameTimestamp for a time far in the future.